pub enum CIP25ChunkableString {
Single(CIP25String64),
Chunked(Vec<CIP25String64>),
}Expand description
A String that may or may not be chunked into 64-byte chunks to be able to conform to Cardano TX Metadata limitations. Unless you have good reasons, you should be using the From<&str> trait to construct this:
use cml_cip25::CIP25ChunkableString;
// automatically chunks this too long string into two chunks:
let chunkable_string = CIP25ChunkableString::from("this can be any length and will automatically be chunked into 64-byte pieces when/if needed");
match chunkable_string {
CIP25ChunkableString::Single(_) => panic!(),
CIP25ChunkableString::Chunked(chunks) => {
assert_eq!(chunks[0].to_str(), "this can be any length and will automatically be chunked into 64");
assert_eq!(chunks[1].to_str(), "-byte pieces when/if needed");
},
}Variants
Single(CIP25String64)
Chunked(Vec<CIP25String64>)
Implementations
Sourceimpl CIP25ChunkableString
impl CIP25ChunkableString
Sourcepub fn new_single(single: CIP25String64) -> Self
pub fn new_single(single: CIP25String64) -> Self
Construct from a single <=64 byte string chunk. If size is not known or for simplicity use From<&str> instead
Sourcepub fn new_chunked(chunked: Vec<CIP25String64>) -> Self
pub fn new_chunked(chunked: Vec<CIP25String64>) -> Self
Construct from an explicit list of chunks If size is not known or for simplicity use From<&str> instead